@@ -240,15 +240,10 @@ function build_gettext {
     --disable-shared
 }
 
-function build_ruby {
-  build_package ruby-2.1.6.tar.bz2 --prefix=${TARGET} \
-    --enable-static --disable-shared
-}
-
 function build_boost {
   local -a args properties
 
-  args=(--reconfigure -sICONV_PATH=/usr -j$DRAKETHREADS --prefix=TMPDIR/${TARGET} --libdir=TMPDIR/${TARGET}/lib)
+  args=(--reconfigure -sICONV_PATH=${TARGET} -j$DRAKETHREADS --prefix=TMPDIR/${TARGET} --libdir=TMPDIR/${TARGET}/lib)
   properties=(toolset=clang link=static variant=release)
   if [[ -n $CXXFLAGS ]] properties+=(cxxflags="${(q)CXXFLAGS}")
   if [[ -n $LDFLAGS  ]] properties+=(linkflags="${(q)LDFLAGS}")
@@ -266,22 +261,6 @@ function build_cmark {
     -DCMARK_SHARED=OFF
 }
 
-function build_openssl {
-  NO_CONFIGURE=1 build_package openssl
-
-  ./Configure \
-    --prefix=${TARGET} \
-    -L${TARGET}/lib \
-    no-krb5 \
-    --openssldir=${TARGET}/etc/openssl \
-    shared \
-    zlib \
-    darwin64-x86_64-cc
-
-  make
-  $DEBUG build_tarball command "make INSTALL_PREFIX=TMPDIR install"
-}
-
 function build_curl {
   build_package curl \
     --prefix=${TARGET} \
@@ -650,7 +629,6 @@ if [[ -z $@ ]]; then
   build_cmark
   build_boost
   build_qt
-  build_ruby
   build_configured_mkvtoolnix
 
 else
