@@ -61,6 +61,7 @@
 #include "common/strings/parsing.h"
 #include "common/strings/utf8.h"
 #include "common/tags/tags.h"
+#include "common/tags/vorbis.h"
 #include "common/id_info.h"
 #include "common/vobsub.h"
 #include "input/r_matroska.h"
@@ -256,30 +257,6 @@ kax_track_t::fix_display_dimension_parameters() {
   }
 }
 
-void
-kax_track_t::add_track_tags_to_identification(mtx::id::info_c &info) {
-  if (!tags)
-    return;
-
-  for (auto const &tag_elt : *tags) {
-    auto tag = dynamic_cast<KaxTag *>(tag_elt);
-    if (!tag)
-      continue;
-
-    for (auto const &simple_tag_elt : *tag) {
-      auto simple_tag = dynamic_cast<KaxTagSimple *>(simple_tag_elt);
-      if (!simple_tag)
-        continue;
-
-      auto name  = mtx::tags::get_simple_name(*simple_tag);
-      auto value = mtx::tags::get_simple_value(*simple_tag);
-
-      if (!name.empty())
-        info.add(fmt::format("tag_{0}", balg::to_lower_copy(name)), value);
-}
-  }
-}
-
 void
 kax_track_t::discard_track_statistics_tags() {
   if (!tags)
@@ -343,15 +320,9 @@ kax_reader_c::unlace_vorbis_private_data(kax_track_t *t,
                                          unsigned char *buffer,
                                          int size) {
   try {
-    auto temp = memory_c::borrow(buffer, size);
-    std::vector<memory_cptr> blocks = unlace_memory_xiph(temp);
-    if (blocks.size() != 3)
-      return false;
-
-    for (int i = 0; 3 > i; ++i) {
-      t->headers[i]      = blocks[i]->get_buffer();
-      t->header_sizes[i] = blocks[i]->get_size();
-    }
+    t->headers = unlace_memory_xiph(memory_c::borrow(buffer, size));
+    for (auto const &header : t->headers)
+      header->take_ownership();
 
   } catch (...) {
     return false;
@@ -478,6 +449,8 @@ kax_reader_c::verify_vorbis_audio_track(kax_track_t *t) {
   if ((m_writing_app == "mkvmerge") && (-1 != m_writing_app_ver) && (MTX_WRITING_APP_VER(7, 0, 0, 0) > m_writing_app_ver))
     t->ignore_duration_hack = true;
 
+  handle_vorbis_comments(*t);
+
   return true;
 }
 
@@ -1903,14 +1876,14 @@ kax_reader_c::create_tta_audio_packetizer(kax_track_t *t,
 void
 kax_reader_c::create_vorbis_audio_packetizer(kax_track_t *t,
                                              track_info_c &nti) {
-  set_track_packetizer(t, new vorbis_packetizer_c(this, nti, t->headers[0], t->header_sizes[0], t->headers[1], t->header_sizes[1], t->headers[2], t->header_sizes[2]));
+  set_track_packetizer(t, new vorbis_packetizer_c(this, nti, t->headers));
   show_packetizer_info(t->tnum, t->ptzr_ptr);
 }
 
 void
 kax_reader_c::create_wavpack_audio_packetizer(kax_track_t *t,
                                               track_info_c &nti) {
-  nti.m_private_data.reset();
+  nti.m_private_data = t->private_data;
 
   wavpack_meta_t meta;
   meta.bits_per_sample = t->a_bps;
@@ -2724,7 +2697,8 @@ kax_reader_c::identify() {
     } else
       codec_info = track->codec_id;
 
-    track->add_track_tags_to_identification(info);
+    if (track->tags)
+      add_track_tags_to_identification(*track->tags, info);
 
     auto &minimum_timestamp = m_minimum_timestamps_by_track_number[track->track_number];
     if (minimum_timestamp.valid())
@@ -2768,3 +2742,40 @@ kax_reader_c::set_track_packetizer(kax_track_t *t,
   t->ptzr     = add_packetizer(ptzr);
   t->ptzr_ptr = PTZR(t->ptzr);
 }
+
+void
+kax_reader_c::handle_vorbis_comments_cover_art(mtx::tags::converted_vorbis_comments_t const &converted) {
+  for (auto const &picture : converted.m_pictures) {
+    picture->ui_id        = ++m_attachment_id;
+    picture->source_file  = m_ti.m_fname;
+    auto attach_mode      = attachment_requested(picture->ui_id);
+    picture->to_all_files = ATTACH_MODE_TO_ALL_FILES == attach_mode;
+
+    if (ATTACH_MODE_SKIP != attach_mode)
+      add_attachment(picture);
+  }
+}
+
+void
+kax_reader_c::handle_vorbis_comments_tags(mtx::tags::converted_vorbis_comments_t const &converted,
+                                          kax_track_t &t) {
+  if (!converted.m_track_tags && !converted.m_album_tags)
+    return;
+
+  t.tags = mtx::tags::merge(t.tags, mtx::tags::merge(converted.m_track_tags, converted.m_album_tags));
+}
+
+void
+kax_reader_c::handle_vorbis_comments(kax_track_t &t) {
+  auto comments = mtx::tags::parse_vorbis_comments_from_packet(*t.headers[1]);
+  if (!comments.valid())
+    return;
+
+  auto converted = mtx::tags::from_vorbis_comments(comments);
+
+  handle_vorbis_comments_cover_art(converted);
+  handle_vorbis_comments_tags(converted, t);
+
+  comments.m_comments.clear();
+  t.headers[1] = mtx::tags::assemble_vorbis_comments_into_packet(comments);
+}
