@@ -11,7 +11,7 @@
 
 class QAbstractItemView;
 
-namespace mtx { namespace gui { namespace Jobs {
+namespace mtx::gui::Jobs {
 
 enum class QueueStatus {
   Stopped,
@@ -19,7 +19,7 @@ enum class QueueStatus {
 };
 
 class Model: public QStandardItemModel {
-  Q_OBJECT;
+  Q_OBJECT
 protected:
   QHash<uint64_t, JobPtr> m_jobsById;
   QSet<Job const *> m_toBeProcessed;
@@ -127,4 +127,4 @@ public:
   static void convertJobQueueToSeparateIniFiles();
 };
 
-}}}
+}
