@@ -12,6 +12,7 @@
 #include <QProgressDialog>
 #include <QRegularExpression>
 #include <QSettings>
+#include <QSignalBlocker>
 #include <QString>
 #include <QThread>
 #include <QTimer>
@@ -203,7 +204,6 @@ Tab::setupInputControls() {
   setupControlLists();
   setupMoveUpDownButtons();
   setupInputLayout();
-  setupPredefinedTrackNames();
 
   ui->files->setModel(m_filesModel);
   ui->tracks->setModel(m_tracksModel);
@@ -215,6 +215,10 @@ Tab::setupInputControls() {
   cfg.handleSplitterSizes(ui->mergeInputSplitter);
   cfg.handleSplitterSizes(ui->mergeFilesTracksSplitter);
 
+  ui->trackName->lineEdit()->setClearButtonEnabled(true);
+  ui->defaultDuration->lineEdit()->setClearButtonEnabled(true);
+  ui->aspectRatio->lineEdit()->setClearButtonEnabled(true);
+
   // Track & chapter language
   ui->trackLanguage->setup();
   ui->chapterLanguage->setup(true);
@@ -441,7 +445,7 @@ Tab::setupInputToolTips() {
   Util::setToolTip(ui->tracks,    QY("Right-click for actions for all items"));
 
   Util::setToolTip(ui->muxThis,   QY("If set to 'no' then the selected tracks will not be copied to the destination file."));
-  Util::setToolTip(ui->trackName, QY("A name for this track that players can display helping the user chose the right track to play, e.g. \"director's comments\"."));
+  Util::setToolTip(ui->trackName, QY("A name for this track that players can display helping the user choose the right track to play, e.g. \"director's comments\"."));
   Util::setToolTip(ui->trackLanguage,
                    Q("%1 %2")
                    .arg(QY("The language for this track that players can use for automatic track selection and display for the user."))
@@ -501,7 +505,7 @@ Tab::setupInputToolTips() {
   Util::setToolTip(ui->cropping,
                    Q("<p>%1 %2</p><p>%3 %4</p><p>%5</p>")
                    .arg(QYH("Sets the cropping parameters which tell a player to omit a certain number of pixels on the four sides during playback."))
-                   .arg(QYH("This must be comma-separated list of four numbers for the cropping to be used at the left, top, right and bottom, e.g. '0,20,0,20'."))
+                   .arg(QYH("This must be a comma-separated list of four numbers for the cropping to be used at the left, top, right and bottom, e.g. '0,20,0,20'."))
                    .arg(QYH("Note that the video content is not modified by this option."))
                    .arg(QYH("The values are only stored in the track headers."))
                    .arg(QYH("Note also that there are not a lot of players that support the cropping parameters.")));
@@ -542,17 +546,38 @@ Tab::setupInputToolTips() {
                    Q("%1 %2 %3")
                    .arg(QY("Free-form edit field for user defined options for this track."))
                    .arg(QY("What you input here is added after all the other options the GUI adds so that you could overwrite any of the GUI's options for this track."))
-                   .arg(QY("All occurences of the string \"<TID>\" will be replaced by the track's track ID.")));
+                   .arg(QY("All occurrences of the string \"<TID>\" will be replaced by the track's track ID.")));
 }
 
 void
 Tab::setupPredefinedTrackNames() {
+  QSignalBlocker const blocker{ui->trackName};
+
   auto name = ui->trackName->currentText();
+  QMap<TrackType, bool> haveType;
+
+  Util::withSelectedIndexes(ui->tracks, [&](QModelIndex const &idx) {
+    auto track = m_tracksModel->fromIndex(idx);
+    if (track)
+      haveType[track->m_type] = true;
+  });
+
+  QStringList items;
+  auto &settings = Util::Settings::get();
+
+  if (haveType[TrackType::Audio])
+    items += settings.m_mergePredefinedAudioTrackNames;
+  if (haveType[TrackType::Video])
+    items += settings.m_mergePredefinedVideoTrackNames;
+  if (haveType[TrackType::Subtitles])
+    items += settings.m_mergePredefinedSubtitleTrackNames;
+
+  items.sort(Qt::CaseInsensitive);
+  items.erase(std::unique(items.begin(), items.end()), items.end());
 
   ui->trackName->clear();
-  ui->trackName->addItems(Util::Settings::get().m_mergePredefinedTrackNames);
+  ui->trackName->addItems(items);
   ui->trackName->setCurrentText(name);
-
 }
 
 void
@@ -567,6 +592,7 @@ Tab::setupFileIdentificationThread() {
   connect(&worker, &FileIdentificationWorker::identifiedAsXmlSegmentInfo,      this, &Tab::handleIdentifiedXmlSegmentInfo);
   connect(&worker, &FileIdentificationWorker::identifiedAsXmlTags,             this, &Tab::handleIdentifiedXmlTags);
   connect(&worker, &FileIdentificationWorker::playlistScanStarted,             this, &Tab::showScanningPlaylistDialog);
+  connect(&worker, &FileIdentificationWorker::playlistScanFinished,            this, &Tab::hideScanningDirectoryDialog);
   connect(&worker, &FileIdentificationWorker::playlistScanDecisionNeeded,      this, &Tab::selectScanPlaylistPolicy);
   connect(&worker, &FileIdentificationWorker::playlistSelectionNeeded,         this, &Tab::selectPlaylistToAdd);
 
@@ -616,6 +642,7 @@ Tab::onTrackSelectionChanged() {
 
   if (1 < numRows) {
     setInputControlValues(nullptr);
+    setupPredefinedTrackNames();
     Util::enableWidgets(m_allInputControls, true);
     return;
   }
@@ -631,6 +658,7 @@ Tab::onTrackSelectionChanged() {
     return;
 
   setInputControlValues(track);
+  setupPredefinedTrackNames();
 
   if (track->isAudio()) {
     Util::enableWidgets(m_audioControls, true);
@@ -1016,19 +1044,31 @@ Tab::onSetDisplayDimensions() {
 
 void
 Tab::onAspectRatioChanged(QString newValue) {
-  ui->setAspectRatio->setChecked(true);
+  if (!newValue.isEmpty()) {
+    ui->setAspectRatio->setChecked(true);
+    onSetAspectRatio();
+  }
+
   withSelectedTracks([&newValue](auto &track) { track.m_aspectRatio = newValue; }, true);
 }
 
 void
 Tab::onDisplayWidthChanged(QString newValue) {
-  ui->setDisplayWidthHeight->setChecked(true);
+  if (!newValue.isEmpty()) {
+    ui->setDisplayWidthHeight->setChecked(true);
+    onSetDisplayDimensions();
+  }
+
   withSelectedTracks([&newValue](auto &track) { track.m_displayWidth = newValue; }, true);
 }
 
 void
 Tab::onDisplayHeightChanged(QString newValue) {
-  ui->setDisplayWidthHeight->setChecked(true);
+  if (!newValue.isEmpty()) {
+    ui->setDisplayWidthHeight->setChecked(true);
+    onSetDisplayDimensions();
+  }
+
   withSelectedTracks([&newValue](auto &track) { track.m_displayHeight = newValue; }, true);
 }
 
@@ -1271,16 +1311,27 @@ Tab::selectScanPlaylistPolicy(SourceFilePtr const &sourceFile,
   }
 }
 
+void
+Tab::hideScanningDirectoryDialog() {
+  if (!m_scanningDirectoryDialog)
+    return;
+
+  delete m_scanningDirectoryDialog;
+  m_scanningDirectoryDialog = nullptr;
+}
+
 void
 Tab::showScanningPlaylistDialog(int numFilesToScan) {
-  auto progressDialog = new QProgressDialog{ QY("Scanning directory"), QY("Cancel"), 0, numFilesToScan, this };
-  auto &worker        = m_identifier->worker();
+  auto &worker = m_identifier->worker();
 
-  connect(&worker,        &FileIdentificationWorker::playlistScanProgressChanged, progressDialog, &QProgressDialog::setValue);
-  connect(&worker,        &FileIdentificationWorker::playlistScanFinished,        progressDialog, &QProgressDialog::deleteLater);
-  connect(progressDialog, &QProgressDialog::canceled,                             m_identifier,   &FileIdentificationThread::abortPlaylistScan);
+  if (!m_scanningDirectoryDialog)
+    m_scanningDirectoryDialog = new QProgressDialog{ QY("Scanning directory"), QY("Cancel"), 0, numFilesToScan, this };
 
-  progressDialog->show();
+  connect(&worker,                   &FileIdentificationWorker::playlistScanProgressChanged, m_scanningDirectoryDialog, &QProgressDialog::setValue);
+  connect(m_scanningDirectoryDialog, &QProgressDialog::canceled,                             m_identifier,              &FileIdentificationThread::abortPlaylistScan);
+
+  m_scanningDirectoryDialog->setWindowTitle(QY("Scanning directory"));
+  m_scanningDirectoryDialog->show();
 }
 
 void
