@@ -67,9 +67,12 @@ char const * const s_valMergeLastAddingAppendingDecision    = "mergeLastAddingAp
 char const * const s_valMergeLastFixedOutputDirs            = "mergeLastFixedOutputDirs";
 char const * const s_valMergeLastOutputDirs                 = "mergeLastOutputDirs";
 char const * const s_valMergeLastRelativeOutputDirs         = "mergeLastRelativeOutputDirs";
+char const * const s_valMergePredefinedAudioTrackNames      = "mergePredefinedAudioTrackNames";
 char const * const s_valMergePredefinedSplitDurations       = "mergePredefinedSplitDurations";
 char const * const s_valMergePredefinedSplitSizes           = "mergePredefinedSplitSizes";
+char const * const s_valMergePredefinedSubtitleTrackNames   = "mergePredefinedSubttitleTrackNames";
 char const * const s_valMergePredefinedTrackNames           = "mergePredefinedTrackNames";
+char const * const s_valMergePredefinedVideoTrackNames      = "mergePredefinedVideoTrackNames";
 char const * const s_valMergeSetDestinationFromTitle        = "mergeSetDestinationFromTitle";
 char const * const s_valMergeTrackPropertiesLayout          = "mergeTrackPropertiesLayout";
 char const * const s_valMergeUseVerticalInputLayout         = "mergeUseVerticalInputLayout";
