@@ -15,7 +15,7 @@
 #include "mkvtoolnix-gui/watch_jobs/tool.h"
 #include "mkvtoolnix-gui/watch_jobs/tab.h"
 
-namespace mtx { namespace gui { namespace WatchJobs {
+namespace mtx::gui::WatchJobs {
 
 Tool::Tool(QWidget *parent,
            QMenu *jobOutputMenu)
@@ -114,8 +114,10 @@ int
 Tool::tabIndexForJobID(uint64_t id)
   const {
   for (int idx = 1, numTabs = ui->widgets->count(); idx < numTabs; ++idx) {
-    auto tab = static_cast<Tab *>(ui->widgets->widget(idx));
-    if (tab->id() == id)
+    auto tab   = static_cast<Tab *>(ui->widgets->widget(idx));
+    auto tabId = tab->id();
+
+    if (tabId && (*tabId == id))
       return idx;
   }
 
@@ -204,4 +206,4 @@ Tool::nextPreviousWindowActionTexts()
   };
 }
 
-}}}
+}
